#
# This is the server logic of a Shiny web application. You can run the 
# application by clicking 'Run App' above.
#
# Find out more about building applications with Shiny here:
# 
#    http://shiny.rstudio.com/
#

library(shiny)
library(lime)
library(ICEbox)
library(caret)

load("data/model.RData")
credit = read.csv("data/credit0.csv")

load("data/creditnull.RData")

pred_svm_good = function(object, newdata){
  return(predict(object, newdata, type = "prob")[,2])
}
# Define server logic required to draw a histogram
shinyServer(function(input, output) {
  
   
  output$Proportion <- renderUI({
    
    newcredit = creditnull
    newcredit$Seniority = input$sen.t1
    newcredit$Time = input$time.t1
    newcredit$Age = input$age.t1
    newcredit$Marital = input$marital.t1
    newcredit$Records = ifelse(input$records.t1, "yes_rec", "no_rec")
    newcredit$Job = input$job.t1
    newcredit$Expenses = input$exp.t1
    newcredit$Income = input$income.t1
    newcredit$Assets = input$assets.t1
    newcredit$Amount = input$amount.t1
    newcredit$Price = input$price.t1
    print(newcredit)
    
    predProb = predict(model.svm, newcredit, type = "prob")[,2]
    print(predProb)
    col = ifelse(predProb > 0.5, "green", "red")
    res = paste0("Ваши шансы: <br> <font size = 6 color = ", col, ">",
                 format(predProb*100, digits = 0) ,"% </font> <br> Вам <font color = ", col, ">", 
                 ifelse(predProb > 0.5, "дадут", "не дадут"),"</font> кредит ")
    print(res)
    HTML(res)
    
  })
  output$int.t1 <- renderPlot({
    
    if(input$interp.t1){
      newcredit = creditnull
      newcredit$Seniority = input$sen.t1
      newcredit$Time = input$time.t1
      newcredit$Age = input$age.t1
      newcredit$Marital = input$marital.t1
      newcredit$Records = ifelse(input$records.t1, "yes_rec", "no_rec")
      newcredit$Job = input$job.t1
      newcredit$Expenses = input$exp.t1
      newcredit$Income = input$income.t1
      newcredit$Assets = input$assets.t1
      newcredit$Amount = input$amount.t1
      newcredit$Price = input$price.t1
      
      predProb = predict(model.svm, newcredit, type = "prob")[,2]
      newcredit$Status = ifelse(predProb > 0.5, "good", "bad")
      explain_svm = lime(x = rbind(newcredit,credit[c(1:200, 1000:1800),]), model = model.svm)
      explain_ex_svm = lime::explain(x = newcredit, 
                                     explainer = explain_svm,
                                     n_features = 10,
                                     label = "good")
      plot_features(explain_ex_svm)
    }

  })
  
  output$iceplot <- renderPlot({
    modelICE_svm = ice(model.svm, X = credit[1:300,], 
                       predictor = input$vars, predictfcn = pred_svm_good)
   if (input$category == "None") 
      plot(modelICE_svm, plot_orig_pts_preds = FALSE)
   else plot(modelICE_svm, plot_orig_pts_preds = FALSE, color_by = input$category)
  })
  
})
