#
# This is the user-interface definition of a Shiny web application. You can
# run the application by clicking 'Run App' above.
#
# Find out more about building applications with Shiny here:
# 
#    http://shiny.rstudio.com/
#

library(shiny)
load("data/creditnull.RData")

shinyUI(fluidPage(
  
  # Application title
  titlePanel("Интерпретация алгоритмов машинного обучения"),
  
  tabsetPanel(
    ## tab 1
    tabPanel("Кредит",
      titlePanel("LIME: решение по кредиту"),
       sidebarLayout(
        sidebarPanel(
          checkboxInput("records.t1",
                        "была задолженность по кредиту"),
          sliderInput("age.t1",
                      "Возраст:",
                      min = 18,
                      max = 75,
                      value = 30),
          selectInput("marital.t1",
                      "Семейное положение:",
                      choices = levels(creditnull$Marital),
                      selected = "не женат / не замужем"),
          selectInput("job.t1",
                      "Тип занятости:",
                      choices = levels(creditnull$Job)),
          sliderInput("sen.t1",
                      "Опыт работы (годы):",
                      min = 0,
                      max = 50,
                      value = 5),
          sliderInput("exp.t1",
                      "Затраты:",
                      min = 0,
                      max = 200,
                      value = 60),
          sliderInput("income.t1",
                      "Доходы:",
                      min = 0,
                      max = 1000,
                      value = 90),
          sliderInput("assets.t1",
                      "Накопления:",
                      min = 0,
                      max = 300000,
                      value = 0,
                      step = 100),
          hr(),
          sliderInput("time.t1",
                      "Срок кредита (месяцы):",
                      min = 6,
                      max = 60,
                      value = 24,
                      step = 6),
          sliderInput("price.t1",
                      "Общая стоимость товара:",
                      min = 100,
                      max = 5000,
                      value = 1000),
          sliderInput("amount.t1",
                      "Запрашиваемая сумма:",
                      min = 100,
                      max = 5000,
                      value = 1000)
        ),
        
        # Show a plot of the generated distribution
        mainPanel(
          htmlOutput("Proportion"),
          checkboxInput("interp.t1", "Показать интерпретацию"),
          plotOutput("int.t1")
        )
      )
    ),
    
    
    ## tab 2
    tabPanel("ICE",
             titlePanel("Влияние отдельных признаков"),
             sidebarLayout(
               sidebarPanel(
                 selectInput("vars",
                             "Выберите переменную для исследования:",
                             choices = c("Опыт работы" = "Seniority", 
                                         "Срок кредита" = "Time", 
                                         "Возраст" = "Age", 
                                         "Затраты" = "Expenses",  
                                         "Доход" = "Income", 
                                         "Накопления" = "Assets", 
                                         "Размер кредита" = "Amount", 
                                         "Стоимость товара" = "Price" )),
                 selectInput("category",
                             "Выберите категорию:",
                             choices = c("Нет" = "None",
                                         "Есть ли задолженность" = "Records", 
                                         "Семейный статус" = "Marital"))
               ),
               
               # Show a plot of the generated distribution
               mainPanel(
                 plotOutput("iceplot")
               )
             )
    
    )
  
  )
  

))
